pub enum Move {
Old(String),
New(String),
Other,
}Expand description
This element may only appear below <Menu>. The <Move> element contains pairs of <Old>/<New> elements indicating how to rename a descendant of the current <Menu>. If the destination path already exists, the moved menu is merged with the destination menu see the section called “Merging” for details.
<Move> is used primarily to fix up legacy directories. For example, say you are merging a <LegacyDir> with folder names that don’t match the current hierarchy; the legacy folder names can be moved to the new names, where they will be merged with the new folders.
<Move> is also useful for implementing menu editing, see the section called “Menu editing”.
Variants
Old(String)
This element may only appear below <Move>, and must be followed by a <New> element. The content of both <Old> and <New> should be a menu path, slash-separated concatenation of <Name> fields, see Menu path. Paths are interpreted relative to the menu containing the <Move> element.
New(String)
This element may only appear below <Move>, and must be preceded by an <Old> element. The <New> element specifies the new path for the preceding <Old> element.