pub enum Rules {
Filename(String),
Category(String),
All(Vec<Rules>),
And(Vec<Rules>),
Or(Vec<Rules>),
Not(Vec<Rules>),
Other,
}Variants
Filename(String)
The <Filename> element is the most basic matching rule. It matches a desktop entry if the desktop entry has the given desktop-file id. See Desktop-File Id.
Category(String)
The <Category> element is another basic matching predicate. It matches a desktop entry if the desktop entry has the given category in its Menu field.
All(Vec<Rules>)
The <All> element is a matching rule that matches all desktop entries.
And(Vec<Rules>)
The <And> element contains a list of matching rules. If each of the matching rules inside the <And> element match a desktop entry, then the entire <And> rule matches the desktop entry.
Or(Vec<Rules>)
The <Or> element contains a list of matching rules. If any of the matching rules inside the <Or> element match a desktop entry, then the entire <Or> rule matches the desktop entry.
Not(Vec<Rules>)
The <Not> element contains a list of matching rules. If any of the matching rules inside the <Not> element matches a desktop entry, then the entire <Not> rule does not match the desktop entry. That is, matching rules below <Not> have a logical OR relationship.